@@ -17,20 +17,16 @@ test_that("curve_seg is good", {
     function(...) num <<- num + 1
   }
 
-  with_mock(
-    `graphics::polygon` = mypolygon_func <- mypolygon(),
-    `graphics::lines`   = mylines_func   <- mylines(),
-    curveseg(0, 0, 1, 1, colorstyle = "color")
-  )
+  mockery::stub(curveseg, "polygon", mypolygon_func <- mypolygon())
+  mockery::stub(curveseg, "lines", mylines_func <- mylines())
+  curveseg(0, 0, 1, 1, colorstyle = "color")
 
   expect_equal(mypolygon_func(), 50)
   expect_equal(mylines_func(),   99)
 
-  with_mock(
-    `graphics::polygon` = mypolygon_func <- mypolygon(),
-    `graphics::lines`   = mylines_func   <- mylines(),
-    curveseg(0, 0, 1, 1, colorstyle = "color", curvestyle = "line")
-  )
+  mockery::stub(curveseg, "polygon", mypolygon_func <- mypolygon())
+  mockery::stub(curveseg, "lines", mylines_func <- mylines())
+  curveseg(0, 0, 1, 1, colorstyle = "color", curvestyle = "line")
 
   expect_equal(mypolygon_func(), 50)
   expect_equal(mylines_func(),   99)
